//
//  YHResignAppointedScheduleLineView.swift
//  galaxy
//
//  Created by edy on 2024/10/10.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHScheduleLineStepModel {
    
    var index: Int = 0
    var title: String = ""
    var time: String = ""
    var isNeedUserAction: Bool = true // 该步骤是否需要用户操作
    
    init(title: String, time: String, isNeedUserAction: Bool = true) {
        self.title = title
        self.time = time
        self.isNeedUserAction = isNeedUserAction
    }
}

class YHResignAppointedScheduleLineView: UIView {

    var steps:[YHScheduleLineStepModel] = {
        let model1 = YHScheduleLineStepModel(title: "入境香港准备", time: "")
        let model2 = YHScheduleLineStepModel(title: "已确认在港", time: "2024-03-14")
        let model3 = YHScheduleLineStepModel(title: "银河递交续签资料", time: "2024-03-14", isNeedUserAction: false)
        let model4 = YHScheduleLineStepModel(title: "查看递交回执", time: "2024-03-14")
        let model5 = YHScheduleLineStepModel(title: "在港等待获批/离港", time: "")
        let model6 = YHScheduleLineStepModel(title: "在港等缴费领取新签证", time: "")
        let model7 = YHScheduleLineStepModel(title: "更新续签旅行证件", time: "")
        return [model1, model2, model3, model4, model5, model6, model7]
    }()
    
    lazy var collectView: UICollectionView = {
        // 设置布局方向
        let flowLayout = UICollectionViewFlowLayout()
        flowLayout.minimumInteritemSpacing = 0.0
        flowLayout.minimumLineSpacing = 0.0
        flowLayout.scrollDirection = .horizontal
        
        let collectinoView = UICollectionView(frame: .zero, collectionViewLayout: flowLayout)
        collectinoView.backgroundColor = .init(hex: 0xF8F9FB)
        collectinoView.register(YHResignAppointedScheduleLineCollectCell.self, forCellWithReuseIdentifier:YHResignAppointedScheduleLineCollectCell.cellReuseIdentifier)
        collectinoView.delegate = self
        collectinoView.dataSource = self
        collectinoView.bounces = false
        collectinoView.showsHorizontalScrollIndicator = false
        return collectinoView
    }()
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        createUI()
    }
    
    func createUI() {
        self.addSubview(collectView)
        collectView.reloadData()
        collectView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
    }
}

extension YHResignAppointedScheduleLineView: UICollectionViewDelegate, UICollectionViewDataSource, UICollectionViewDelegateFlowLayout  {
    
        // 返回单元格数量
        func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
            
            return steps.count
        }
        
        // 返回每个单元格的大小
        func collectionView(_ collectionView: UICollectionView, layout collectionViewLayout: UICollectionViewLayout, sizeForItemAt indexPath: IndexPath) -> CGSize {
            
            if 0 <= indexPath.item && indexPath.item < steps.count {
                let model = steps[indexPath.item]
                let size = self.getwith(font: UIFont.PFSC_R(ofSize: 11), height: 15, string: model.title)
                var width = ceil(Double(size.width))
                if width < 65.0 {
                    width = 65.0
                }
                width += 18.0
                return CGSize(width: width, height: 84.0)
            }
            return .zero
        }
        
        // 返回自定义单元格
        func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
            let cell = collectionView.dequeueReusableCell(withReuseIdentifier: YHResignAppointedScheduleLineCollectCell.cellReuseIdentifier, for: indexPath) as! YHResignAppointedScheduleLineCollectCell
            if 0 <= indexPath.item && indexPath.item < steps.count {
                let model = steps[indexPath.item]
                model.index = indexPath.item+1
                cell.updateModel(model)
            }
            return cell
        }
    
    func collectionView(_ collectionView: UICollectionView, didSelectItemAt indexPath: IndexPath) {
        if 0 <= indexPath.item && indexPath.item < steps.count {
            let model = steps[indexPath.item]
        }
    }
    
    // 计算文字宽度大小
    func getwith(font: UIFont, height: CGFloat, string: String) -> CGSize {
        let size = CGSize.init(width: CGFloat(MAXFLOAT), height: height)
        let dic = [NSAttributedString.Key.font: font] // swift 4.2
        let strSize = string.boundingRect(with: size, options: [.usesLineFragmentOrigin], attributes: dic, context:nil).size
        return CGSizeMake(ceil(strSize.width), strSize.height)
    }
}

